Index: pkg/dartino_compiler/lib/src/device_type.dart |
diff --git a/pkg/fletchc/lib/src/device_type.dart b/pkg/dartino_compiler/lib/src/device_type.dart |
similarity index 89% |
rename from pkg/fletchc/lib/src/device_type.dart |
rename to pkg/dartino_compiler/lib/src/device_type.dart |
index 32c0b6a2cc19740f85ed32a114e562afee1c97be..7cf500de6aeb24667ade637910becfa41699eb8b 100644 |
--- a/pkg/fletchc/lib/src/device_type.dart |
+++ b/pkg/dartino_compiler/lib/src/device_type.dart |
@@ -2,8 +2,8 @@ |
// for details. All rights reserved. Use of this source code is governed by a |
// BSD-style license that can be found in the LICENSE.md file. |
-/// Describes the different target device types for the fletch system. |
-library fletch_device_type; |
+/// Describes the different target device types for the dartino system. |
+library dartino_device_type; |
enum DeviceType { |
embedded, |